==> dooit-1.0.1.tar.gz: dooit-1.0.1/README.md <==
<img src="https://user-images.githubusercontent.com/97718086/174438959-d8887b62-76de-4587-9619-91a4ecd6e1d6.png" align="right" alt="Todo Icon" width="150" height="150">

# Dooit ✔️
*A todo manager that you didn't ask for, but needed !* \
to make sure that you complete your tasks on time ;)

[![GitHub issues](https://img.shields.io/github/issues/kraanzu/dooit?color=red&style=for-the-badge)](https://github.com/kraanzu/doit/issues)
[![GitHub stars](https://img.shields.io/github/stars/kraanzu/dooit?color=green&style=for-the-badge)](https://github.com/kraanzu/doit/stargazers)
[![GitHub license](https://img.shields.io/github/license/kraanzu/dooit?color=yellow&style=for-the-badge)](https://github.com/kraanzu/doit/blob/main/LICENSE)
[![Support Server](https://img.shields.io/discord/989186205025464390.svg?label=Discord&logo=Discord&colorB=7289da&style=for-the-badge)](https://discord.gg/WA2ER9MBWa)

# Installation 🔨

Dooit can be installed with various package managers!

### With Pip 🐍

You can install dooit easily using a python one-liner. Make sure `~/.local/bin` is in `$PATH`

```bash
pip install dooit
```

### With AUR helper 📦
```
yay -S dooit-git
```

### With Homebrew 🍻

You can install the latest stable version of dooit with [Homebrew](https://brew.sh):

```bash
brew install dooit
```

Alternatively, you can install the most recent development version of dooit:

```bash
brew install dooit --HEAD
```

# Features 🌟

> Some features that dooit comes with:

- An interactive & beautiful UI
- An API automate stuff with python scripts and integrate with other apps (!plugin support in pipeline!)
- Configurable icons, themes and bar!
- Vim like keybindings
- Topicwise separated Todo Lists (With branching)
- Nested todos!
- Support for recurrence todos
- Sort options with menu (Name, Date, Urgency, Status)
- Search & edit on the fly!

**Note: See [CHANGELOG.md]() to get more details on changes and feature additions!**

# Usage and configuration :gear:
After launching the app, You can press the `?` key to get started with the app :)\
You can also tweak everything including the UI, keybindings and status bar to your liking\
Head over to [wiki](https://github.com/kraanzu/dooit/wiki/Configuration) to know more!


# Screenshots 🖼️
![Screenshot](https://user-images.githubusercontent.com/97718086/221467485-fae198f7-51b1-4a71-91d9-88b51897aeeb.png)

# Contribution 🤝
- Want to contribute? Feel free to open a PR! 😸
- Got some ideas for improvements? I'm all ears! 👂

----------------------------

#### Other TUI projects 🤓 :
If you liked dooit then you might wanna try out some of my other TUI projects as well
- [termtyper](https://github.com/kraanzu/termtyper) - A typing-test app for terminal
- [gupshup](https://github.com/kraanzu/gupshup) - A localhost TUI chat client

==> dooit-2.1.0.tar.gz: dooit-2.1.0/README.md <==
<img src="https://user-images.githubusercontent.com/97718086/174438959-d8887b62-76de-4587-9619-91a4ecd6e1d6.png" align="right" alt="Todo Icon" width="150" height="150">

# Dooit ✔️
*A todo manager that you didn't ask for, but needed !* \
to make sure that you complete your tasks on time ;)

[![GitHub issues](https://img.shields.io/github/issues/kraanzu/dooit?color=red&style=for-the-badge)](https://github.com/kraanzu/doit/issues)
[![GitHub stars](https://img.shields.io/github/stars/kraanzu/dooit?color=green&style=for-the-badge)](https://github.com/kraanzu/doit/stargazers)
[![GitHub license](https://img.shields.io/github/license/kraanzu/dooit?color=yellow&style=for-the-badge)](https://github.com/kraanzu/doit/blob/main/LICENSE)
[![Support Server](https://img.shields.io/discord/989186205025464390.svg?label=Discord&logo=Discord&colorB=7289da&style=for-the-badge)](https://discord.gg/WA2ER9MBWa)

# Installation 🔨

Dooit can be installed with various package managers!

### With Pip 🐍

> **Note**
Make sure your `python local bin` is in `$PATH`

You can install dooit easily using a python one-liner. 

```bash
pip install dooit
```

### With AUR helper 📦
```
yay -S dooit-git
```

### With Homebrew 🍻

You can install the latest stable version of dooit with [Homebrew](https://brew.sh):

```bash
brew install dooit
```

Alternatively, you can install the most recent development version of dooit:

```bash
brew install dooit --HEAD
```

# Features 🌟

> Some features that dooit comes with:

- An interactive & beautiful UI
- Configurable icons, themes and bar!
- Vim like keybindings
- Topicwise separated Todo Lists (With branching)
- Nested todos!
- Support for recurrence todos
- Sort options with menu (Name, Date, Urgency, Status)

**Note: See [CHANGELOG.md]() to get more details on changes and feature additions!**

# Usage and configuration :gear:
After launching the app, You can press the `?` key to get started with the app :)\
You can also tweak everything including the UI, keybindings and status bar to your liking\
Head over to [wiki](https://github.com/kraanzu/dooit/wiki/Configuration) to know more!


# Screenshots 🖼️
![dooit](https://github.com/kraanzu/dooit/assets/97718086/55d37e59-e651-45e7-9c8d-4321e566b655)

# Contribution 🤝
- Want to contribute? Feel free to open a PR! 😸
- Got some ideas for improvements? I'm all ears! 👂

----------------------------

#### Other TUI projects 🤓 :
If you liked dooit then you might wanna try out some of my other TUI projects as well
- [termtyper](https://github.com/kraanzu/termtyper) - A typing-test app for terminal
- [gupshup](https://github.com/kraanzu/gupshup) - A localhost TUI chat client
